==> hbase-shaded-jersey-3.4.0-sources.jar: org/apache/hbase/thirdparty/org/glassfish/jersey/server/monitoring/ResponseMXBean.java <==
/*
 * Copyright (c) 2013, 2018 Oracle and/or its affiliates. All rights reserved.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v. 2.0, which is available at
 * http://www.eclipse.org/legal/epl-2.0.
 *
 * This Source Code may also be made available under the following Secondary
 * Licenses when the conditions for such availability set forth in the
 * Eclipse Public License v. 2.0 are satisfied: GNU General Public License,
 * version 2 with the GNU Classpath Exception, which is available at
 * https://www.gnu.org/software/classpath/license.html.
 *
 * SPDX-License-Identifier: EPL-2.0 OR GPL-2.0 WITH Classpath-exception-2.0
 */

package org.apache.hbase.thirdparty.org.glassfish.org.apache.hbase.thirdparty.jersery.server.monitoring;

import java.util.Map;

/**
 * MXBean interface of response MXBean.
 *
 * @author Miroslav Fuksa
 */
public interface ResponseMXBean {
    /**
     * Returns statistics of response codes produces by the application. Keys of a returned
     * map are response status codes and values is the the count of responses with these
     * status count. Values are measured since start of the application.
     *
     * @return Map with status codes keys and count as values.
     */
    public Map<Integer, Long> getResponseCodesToCountMap();

    /**
     * Returns the response code of a last response written by the application.
     *
     * @return Last response status code.
     */
    public Integer getLastResponseCode();
}

==> hbase-shaded-jersey-4.1.2-sources.jar: org/apache/hbase/thirdparty/org/glassfish/jersey/server/monitoring/ResponseMXBean.java <==
/*
 * Copyright (c) 2013, 2018 Oracle and/or its affiliates. All rights reserved.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v. 2.0, which is available at
 * http://www.eclipse.org/legal/epl-2.0.
 *
 * This Source Code may also be made available under the following Secondary
 * Licenses when the conditions for such availability set forth in the
 * Eclipse Public License v. 2.0 are satisfied: GNU General Public License,
 * version 2 with the GNU Classpath Exception, which is available at
 * https://www.gnu.org/software/classpath/license.html.
 *
 * SPDX-License-Identifier: EPL-2.0 OR GPL-2.0 WITH Classpath-exception-2.0
 */

package org.apache.hbase.thirdparty.org.glassfish.org.apache.hbase.thirdparty.jersey.server.monitoring;

import java.util.Map;

/**
 * MXBean interface of response MXBean.
 *
 * @author Miroslav Fuksa
 */
public interface ResponseMXBean {
    /**
     * Returns statistics of response codes produces by the application. Keys of a returned
     * map are response status codes and values is the the count of responses with these
     * status count. Values are measured since start of the application.
     *
     * @return Map with status codes keys and count as values.
     */
    public Map<Integer, Long> getResponseCodesToCountMap();

    /**
     * Returns the response code of a last response written by the application.
     *
     * @return Last response status code.
     */
    public Integer getLastResponseCode();
}
